Quickstart
==========
BlocksNet quick start guide

Installation
------------

.. include:: ../../../README.rst
   :start-after: .. installation-start
   :end-before: .. installation-end

How to use
----------

.. include:: ../../../README.rst
   :start-after: .. use-start
   :end-before: .. use-end
